@@ -6,7 +6,7 @@ use riptun::AsyncStdTun;
 const NUM_QUEUES: usize = 5;
 
 pub async fn run() {
-    let (mut async_dev, name) = match AsyncStdTun::new("rip%d", NUM_QUEUES) {
+    let mut async_dev = match AsyncStdTun::new("rip%d", NUM_QUEUES) {
         Ok(async_dev) => async_dev,
         Err(err) => {
             println!("[ERROR] => {}", err);
@@ -14,12 +14,12 @@ pub async fn run() {
         }
     };
 
-    println!("[INFO] => Created new virtual device: {}", name);
+    println!("[INFO] => Created new virtual device: {}", async_dev.name());
 
     let mut handles = Vec::with_capacity(NUM_QUEUES);
     for (idx, queue) in async_dev.drain(..).enumerate() {
         let handle = smol::spawn(async move {
-            let mut buffer: [u8; 65535] = [0x00; 65535];
+            let mut buffer: [u8; 1500] = [0x00; 1500];
             loop {
                 let read = match queue.recv(&mut buffer).await {
                     Ok(read) => read,
