@@ -7,7 +7,7 @@ const NUM_QUEUES: usize = 5;
 
 #[async_std::main]
 pub async fn main() {
-    let (async_dev, name) = match AsyncStdTun::new("rip%d", NUM_QUEUES) {
+    let async_dev = match AsyncStdTun::new("rip%d", NUM_QUEUES) {
         Ok(async_dev) => async_dev,
         Err(err) => {
             println!("[ERROR] => {}", err);
@@ -15,9 +15,9 @@ pub async fn main() {
         }
     };
 
-    println!("[INFO] => Created new virtual device: {}", name);
+    println!("[INFO] => Created new virtual device: {}", async_dev.name());
 
-    let mut buffer: [u8; 65535] = [0x00; 65535];
+    let mut buffer: [u8; 1500] = [0x00; 1500];
     loop {
         let read = match async_dev.recv(&mut buffer).await {
             Ok(read) => read,
