@@ -8,7 +8,7 @@ use riptun::Tun;
 const NUM_QUEUES: usize = 5;
 
 pub fn main() {
-    let (async_dev, name) = match Tun::new("rip%d", NUM_QUEUES) {
+    let async_dev = match Tun::new("rip%d", NUM_QUEUES) {
         Ok(async_dev) => async_dev,
         Err(err) => {
             println!("[ERROR] => {}", err);
@@ -16,7 +16,7 @@ pub fn main() {
         }
     };
 
-    println!("[INFO] => Created new virtual device: {}", name);
+    println!("[INFO] => Created new virtual device: {}", async_dev.name());
 
     let mut handles = Vec::with_capacity(NUM_QUEUES);
     let async_dev = Arc::new(async_dev);
